summaryrefslogtreecommitdiff
path: root/tests/basic
diff options
context:
space:
mode:
authorClaude Paroz <claude@2xlibre.net>2017-01-26 20:58:33 +0100
committerClaude Paroz <claude@2xlibre.net>2017-02-07 09:04:04 +0100
commitc651331b34b7c3841c126959e6e52879bc6f0834 (patch)
tree3f93aeb92fc91dcc61649b46d9f26f7aaaff978b /tests/basic
parent4353640ea9495d58fabd0357253b82de3b069408 (diff)
downloaddjango-c651331b34b7c3841c126959e6e52879bc6f0834.tar.gz
Converted usage of ugettext* functions to their gettext* aliases
Thanks Tim Graham for the review.
Diffstat (limited to 'tests/basic')
-rw-r--r--tests/basic/tests.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/tests/basic/tests.py b/tests/basic/tests.py
index 571088da40..12da117edf 100644
--- a/tests/basic/tests.py
+++ b/tests/basic/tests.py
@@ -9,7 +9,7 @@ from django.test import (
SimpleTestCase, TestCase, TransactionTestCase, skipIfDBFeature,
skipUnlessDBFeature,
)
-from django.utils.translation import ugettext_lazy
+from django.utils.translation import gettext_lazy
from .models import Article, ArticleSelectOnSave, SelfRef
@@ -310,13 +310,13 @@ class ModelTest(TestCase):
pub_date__year=2008).extra(select={'dashed-value': '1', 'undashedvalue': '2'})
self.assertEqual(articles[0].undashedvalue, 2)
- def test_create_relation_with_ugettext_lazy(self):
+ def test_create_relation_with_gettext_lazy(self):
"""
ugettext_lazy objects work when saving model instances
through various methods. Refs #10498.
"""
notlazy = 'test'
- lazy = ugettext_lazy(notlazy)
+ lazy = gettext_lazy(notlazy)
Article.objects.create(headline=lazy, pub_date=datetime.now())
article = Article.objects.get()
self.assertEqual(article.headline, notlazy)
@@ -310,13 +310,13 @@ class ModelTest(TestCase):
"""
- ugettext_lazy objects work when saving model instances
+ gettext_lazy objects work when saving model instances
through various methods. Refs #10498.
"""